==> haskell-network-protocol-xmpp-0.5.2-25-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-network-protocol-xmpp.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 network-protocol-xmpp
version:              0.5.2
visibility:           public
id:                   network-protocol-xmpp-0.5.2-1K1cx9Ad3hNLJvulvijRQA
key:                  network-protocol-xmpp-0.5.2-1K1cx9Ad3hNLJvulvijRQA
license:              GPL-3.0-only
maintainer:           Stephen Paul Weber <singpolyma@singpolyma.net>
author:
    John Millikin <jmillikin@gmail.com>, Stephan Maka <stephan@spaceboyz.net>

stability:            experimental
homepage:             https://git.sr.ht/~singpolyma/network-protocol-xmpp
synopsis:             Client library for the XMPP protocol.
category:             Network
abi:                  21e849f94eb0e10adb098f9d00876653
exposed:              True
exposed-modules:      Network.Protocol.XMPP Network.Protocol.XMPP.Internal
hidden-modules:
    Network.Protocol.XMPP.Client
    Network.Protocol.XMPP.Client.Authentication
    Network.Protocol.XMPP.Client.Features
    Network.Protocol.XMPP.Component Network.Protocol.XMPP.Connections
    Network.Protocol.XMPP.Handle Network.Protocol.XMPP.JID
    Network.Protocol.XMPP.Monad Network.Protocol.XMPP.Stanza
    Network.Protocol.XMPP.XML Network.Protocol.XMPP.String

import-dirs:          /usr/lib/ghc-9.4.8/site-local/network-protocol-xmpp-0.5.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/network-protocol-xmpp-0.5.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/network-protocol-xmpp-0.5.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-network-protocol-xmpp
hs-libraries:         HSnetwork-protocol-xmpp-0.5.2-1K1cx9Ad3hNLJvulvijRQA
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    gnuidn-0.2.2-IHAkK19H4pZ6MGdalqyYN9
    gnutls-0.3-1wEyrLP348rJAMgSWwtqMc
    gsasl-0.3.7-5di2RX669526hFHZ9nNEon
    libxml-sax-0.7.6-G0tQS2Ma6qg9Y14m6sKkGk
    network-3.1.4.0-Lt9YSaQDSdWKRzslp3ePNQ
    network-simple-0.4.5-K7rTpYRczgM8aKfujC12l3 text-2.0.2
    transformers-0.5.6.2 xml-types-0.3.8-IpGyuvvNOu2AH1SOobl25

haddock-interfaces:
    /usr/share/doc/haskell-network-protocol-xmpp/html/network-protocol-xmpp.haddock

haddock-html:         /usr/share/doc/haskell-network-protocol-xmpp/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-network-protocol-xmpp-0.5.2-26-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-network-protocol-xmpp.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 network-protocol-xmpp
version:              0.5.2
visibility:           public
id:                   network-protocol-xmpp-0.5.2-62wUf0nOofTBuYDrbr5htw
key:                  network-protocol-xmpp-0.5.2-62wUf0nOofTBuYDrbr5htw
license:              GPL-3.0-only
maintainer:           Stephen Paul Weber <singpolyma@singpolyma.net>
author:
    John Millikin <jmillikin@gmail.com>, Stephan Maka <stephan@spaceboyz.net>

stability:            experimental
homepage:             https://git.sr.ht/~singpolyma/network-protocol-xmpp
synopsis:             Client library for the XMPP protocol.
category:             Network
abi:                  2d1ac55bdee43dbf4b71ef670a898d73
exposed:              True
exposed-modules:      Network.Protocol.XMPP Network.Protocol.XMPP.Internal
hidden-modules:
    Network.Protocol.XMPP.Client
    Network.Protocol.XMPP.Client.Authentication
    Network.Protocol.XMPP.Client.Features
    Network.Protocol.XMPP.Component Network.Protocol.XMPP.Connections
    Network.Protocol.XMPP.Handle Network.Protocol.XMPP.JID
    Network.Protocol.XMPP.Monad Network.Protocol.XMPP.Stanza
    Network.Protocol.XMPP.XML Network.Protocol.XMPP.String

import-dirs:          /usr/lib/ghc-9.4.8/site-local/network-protocol-xmpp-0.5.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/network-protocol-xmpp-0.5.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/network-protocol-xmpp-0.5.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-network-protocol-xmpp
hs-libraries:         HSnetwork-protocol-xmpp-0.5.2-62wUf0nOofTBuYDrbr5htw
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    gnuidn-0.2.2-IHAkK19H4pZ6MGdalqyYN9
    gnutls-0.3-1wEyrLP348rJAMgSWwtqMc
    gsasl-0.3.7-5di2RX669526hFHZ9nNEon
    libxml-sax-0.7.6-IxgRp2mIpCe70Z9lmjYEv9
    network-3.1.4.0-KmVGd8MQrab5lGMy9eMLcZ
    network-simple-0.4.5-IQ1gyChRQDCLyRXcwSMz4l text-2.0.2
    transformers-0.5.6.2 xml-types-0.3.8-IpGyuvvNOu2AH1SOobl25

haddock-interfaces:
    /usr/share/doc/haskell-network-protocol-xmpp/html/network-protocol-xmpp.haddock

haddock-html:         /usr/share/doc/haskell-network-protocol-xmpp/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
